aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib/pubkey/keypair/keypair.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/pubkey/keypair/keypair.h')
-rw-r--r--src/lib/pubkey/keypair/keypair.h44
1 files changed, 40 insertions, 4 deletions
diff --git a/src/lib/pubkey/keypair/keypair.h b/src/lib/pubkey/keypair/keypair.h
index 7fcde3216..894749583 100644
--- a/src/lib/pubkey/keypair/keypair.h
+++ b/src/lib/pubkey/keypair/keypair.h
@@ -18,28 +18,64 @@ namespace KeyPair {
* Tests whether the key is consistent for encryption; whether
* encrypting and then decrypting gives to the original plaintext.
* @param rng the rng to use
* @param key the key to test
* @param padding the encryption padding method to use
* @return true if consistent otherwise false
*/
BOTAN_DLL bool
encryption_consistency_check(RandomNumberGenerator& rng,
- const Private_Key& key,
+ const Private_Key& private_key,
+ const Public_Key& public_key,
const std::string& padding);
/**
* Tests whether the key is consistent for signatures; whether a
* signature can be created and then verified
* @param rng the rng to use
* @param key the key to test
* @param padding the signature padding method to use
* @return true if consistent otherwise false
*/
BOTAN_DLL bool
signature_consistency_check(RandomNumberGenerator& rng,
- const Private_Key& key,
+ const Private_Key& private_key,
+ const Public_Key& public_key,
const std::string& padding);
+/**
+* Tests whether the key is consistent for encryption; whether
+* encrypting and then decrypting gives to the original plaintext.
+* @param rng the rng to use
+* @param key the key to test
+* @param padding the encryption padding method to use
+* @return true if consistent otherwise false
+*/
+inline bool
+encryption_consistency_check(RandomNumberGenerator& rng,
+ const Private_Key& key,
+ const std::string& padding)
+ {
+ return encryption_consistency_check(rng, key, key, padding);
+ }
+
+/**
+* Tests whether the key is consistent for signatures; whether a
+* signature can be created and then verified
+* @param rng the rng to use
+* @param key the key to test
+* @param padding the signature padding method to use
+* @return true if consistent otherwise false
+*/
+inline bool
+signature_consistency_check(RandomNumberGenerator& rng,
+ const Private_Key& key,
+ const std::string& padding)
+ {
+ return signature_consistency_check(rng, key, key, padding);
+ }
+
}
}
@@ -18,28 +18,64 @@ namespace KeyPair {
* encrypting and then decrypting gives to the original plaintext.
* @param rng the rng to use
-* @param key the key to test
+* @param private_key the key to test
+* @param public_key the key to test
* @param padding the encryption padding method to use
* @return true if consistent otherwise false
@@ -18,28 +18,64 @@ namespace KeyPair {
* signature can be created and then verified
* @param rng the rng to use
-* @param key the key to test
+* @param private_key the key to test
+* @param public_key the key to test
* @param padding the signature padding method to use
* @return true if consistent otherwise false